/**
 * @flow
 * Generate class Name for displays
 * @param {string} name - class name
 * @param {array} displays - specified displays
 * @return {string} generated classes
 */
export const generateFlexClassNames = ( name: string, displays ): string =>
{
	return displays.reduce( ( accumulator: string, currentValue: string ): string =>
	{
		return `${ accumulator } ${ name }-${ currentValue }`;
	}, "" );
};

/**
 * Generate Col Class names
 * @param {string} name - class name
 * @param {number} value - value
 * @return {string} - generated class name
 */
export const generateColClassName = ( name: string, value: number ): string =>
{
	if ( Number.isInteger( value ) && value !== 0 )
	{
		return `col-${ name }-${ value }`;
	}

	return `col-${ name }`;
};

export default {};